/*
	ProWesS, PROGS Windowing System
	PROforma, PROGS Font & Raster Manager

	PFconfig : utility program for ProWesS package
		allows easy configuration of PROforma

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	21.10.1996 started
*/

#include "PFConfig.h"

/* === add fonts to the configuration === */

#define PF_FNT_ID "PROforma native font    01"

static Error fontname(char *dir,char *file,char *font)
{
	/* fill in name of "font" for "dir_file" */
	Error err=ERR_OK;
	Channel chid;
	char buff[MAX_LINE];
	struct block { char flag,type; Size len; } bh;

	catch( IOOpenPath(file,OPEN_READ,dir,&chid) );

#undef catch
#define catch(x) do { if (err=(x)) { IOClose(chid); return err; } } while(0)

	/* make sure header is correct */
	catch( IOGetBytes(chid,strlen(PF_FNT_ID),buff,NULL) );
	if (!MEMSame(strlen(PF_FNT_ID),buff,PF_FNT_ID))
		{ IOClose(chid); return ERR_IPAR; }

	catch( IOGetBytes(chid,sizeof(bh),(char *)&bh,NULL) );
	while (bh.type!=1)
	{
		catch( IOPositionMove(chid,bh.len) );
		catch( IOGetBytes(chid,sizeof(bh),(char *)&bh,NULL) );
	}
	IOGetBytes(chid,PF_MAXFONTNAME,font,NULL);

#undef catch
#define catch(x) do { if (err=(x)) return err; } while(0)

	IOClose(chid);
	return err;
}

static Error fontload(PWObject object, char *dir, PWObject menu)
{
	Global *g;
	Error err;
	char *item, *line;
	char string[MAX_LINE+2];
	char font[PF_MAXFONTNAME];

	PWQuery(object,PW_OBJECT_AUXILIARY,&g);
	PWQuery(menu,PW_MENU_SELECTED_FIRST,&item);
	STRFormatPutSafe(string,MAX_LINE,"S +%s",dir);
	THINGCall(PF_THING_NAME,PF_THING_CNFG,1,string);
	catch( LineAdd(g,dir,&g->fpath) );
	while (item)
	{
		if (fontname(dir,item,font)==ERR_OK)
		{
			STRFormatPutSafe(string,MAX_LINE,"P %s;%s",font,item);
			err=THINGCall(PF_THING_NAME,PF_THING_CNFG,1,string);
			if (err) return DisplayError(err);
			if (MEMSearch(';',MAX_LINE,string+2,&line)==ERR_OK) *line='\0';
			catch( LineAdd(g,string+2,&g->fonts) );
		}
		PWQuery(menu,PW_MENU_SELECTED_NEXT,&item);
	}
	return ERR_OK;
}

Error FontAdd(Global *g)
{
	Error err;
	PWObject win,outl;

	catch( PWCreate(NULL,&win,PW_TYPE_FILESELECT,
					PW_FILESELECT_TITLE_TEXT, "select fonts",
					PW_FILESELECT_ACTION, fontload,
					PW_FILESELECT_DIRECTORY, "$PWSDIR_fnt",
					PW_FILESELECT_EXTENSION, "_pff",
					PW_FILESELECT_MULTIPLE,
					PW_OBJECT_AUXILIARY, g,
					NULL) );
	catch( PWQuery(win,PW_FILESELECT_OUTLINE,&outl) );
	catch( PWChange(outl,
					PW_OUTLINE_SLEEP,
					PW_OUTLINE_HELP,
					PW_OUTLINE_HELP_DIRECTORY, "$PWSDIR_doc_",
					PW_OUTLINE_HELP_FILE, "PFconfig_html",
					PW_OUTLINE_HELP_POSITION, "afont",
					NULL) );
	catch( PWChange(win,PW_FILESELECT_ACTIVATE,NULL) );
	return PWRemove(win);
}
