/*
	ProWesS, PROGS Windowing System
	PROforma, PROGS Font & Raster Manager

	PFconfig : utility program for ProWesS package
		allows easy configuration of PROforma

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	29.09.1996 started
	01.10.1996 all driver stuff finished (but not in PROforma_cfg file!)
*/

#include "PFConfig.h"

static Error indicate(PWObject object) { return (Error)object; }

Error init()
{
	Error err;
	PWObject win, objAdd, objCfg, objDef, objMem, objFnt, objExt, objSav=NULL;
	Global g;

	LinkPROforma();

	/* initialise global mem */
	MEMClear(sizeof(Global), &g);
	g.unit=UNIT_MM;
	err=MEMUserInit(max(sizeof(Lines),sizeof(CLines)),100,&g.lines);
	if (err) return DisplayError(err);
	err=ConfigRead(&g);
	if (err) return DisplayError(err);

	catch( PWCreate(NULL,&win,PW_TYPE_OUTLINE,
					PW_OUTLINE_QUIT,
					PW_OUTLINE_QUIT_KEYPRESS, 27,
					PW_OUTLINE_SLEEP,
					PW_OUTLINE_HELP,
					PW_OUTLINE_HELP_DIRECTORY, "$PWSDIR_doc_",
					PW_OUTLINE_HELP_FILE, "PFconfig_html",
					NULL) );

	catch( PWCreate(win,&objAdd,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Add driver",
					PW_LOOSE_KEYPRESS, 'a',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );
	catch( PWCreate(win,&objCfg,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Configure printer driver",
					PW_LOOSE_KEYPRESS, 'c',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );
	catch( PWCreate(win,&objDef,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Default printer selection",
					PW_LOOSE_KEYPRESS, 'd',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );
	catch( PWCreate(win,&objMem,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Memory options",
					PW_LOOSE_KEYPRESS, 'm',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );
	catch( PWCreate(win,&objFnt,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Fonts, add from directory",
					PW_LOOSE_KEYPRESS, 'f',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );
	catch( PWCreate(win,&objExt,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Search directory for fonts",
					PW_LOOSE_KEYPRESS, 's',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );

	err=PWActivate(win);
	while (err)
	{
		if (err!=(Error)objSav) PWChange(win,PW_WINDOW_ORIGIN_RESET,NULL);
		if (err<0)
			return err;
		else if (err==(Error)objAdd)
			catch( DriverAdd(&g) );
		else if (err==(Error)objCfg)
			catch( PrinterConfig(&g) );
		else if (err==(Error)objDef)
			catch( PrinterDefault(&g) );
		else if (err==(Error)objSav)
			catch( ConfigWrite(&g) );
		else if (err==(Error)objMem)
			catch( Memory(&g) );
		else if (err==(Error)objFnt)
			catch( FontAdd(&g) );
		else if (err==(Error)objExt)
			catch( FontPath(&g) );

		if (g.changed && !objSav)
		{
			catch( PWCreate(win,&objSav,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, "Make changes permanent",
					PW_LOOSE_KEYPRESS, 'm',
					PW_LOOSE_ACTION_HIT, indicate,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					NULL) );
		}
		if (!g.changed && objSav)
		{
			PWRemove(objSav);
			objSav=NULL;
		}

		err=PWActivate(win);
	}
	return err;
}
